#  Copyright (C) 1999-2008
#  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
#  For conditions of distribution and use, see copyright notice in "copyright"

package provide DS9 1.0

# Default colormap names
# [msgcat::mc {Grey}]
# [msgcat::mc {Red}]
# [msgcat::mc {Green}]
# [msgcat::mc {Blue}]
# [msgcat::mc {Heat}]
# [msgcat::mc {Cool}]
# [msgcat::mc {Rainbow}]
# [msgcat::mc {Standard}]
# [msgcat::mc {Staircase}]
# [msgcat::mc {Color}]

proc ColorMenu {} {
    global colorbar
    global ds9

    menu $ds9(mb).color

    set id [colorbar list id]
    foreach ii $id {
	set name [colorbar get name $ii]
	$ds9(mb).color add radiobutton -label [msgcat::mc $name] \
	    -variable colorbar(map) \
	    -command "ChangeColormapID $ii"
	incr colorbar(count)
    }

    $ds9(mb).color add separator
    $ds9(mb).color add checkbutton -label [msgcat::mc {Invert Colormap}] \
	-variable colorbar(invert) -command InvertColorbar
    $ds9(mb).color add command -label [msgcat::mc {Reset Colormap}] \
	-command ResetColormap
    $ds9(mb).color add separator
    $ds9(mb).color add checkbutton -label [msgcat::mc {Colorbar Numerics}] \
	-variable view(colorbar,numerics) -command UpdateView
    $ds9(mb).color add separator
    $ds9(mb).color add command -label "[msgcat::mc {Colormap Parameters}]..." \
	-command ColormapDialog
}

proc PrefsDialogColor {} {
    global prefs

    set w $prefs(tabs)

    frame $w.color
    $prefs(tabs) tab configure color -window $w.color -fill both

    frame $w.color.menu -relief ridge -bd 1
    frame $w.color.truecolor -relief ridge -bd 1
    pack $w.color.menu $w.color.truecolor -side top -fill both -expand true

    # Buttons
    PrefsDialogButtons $w.color

    # Default Menu
    set f $w.color.menu.f
    frame $f
    pack $f -anchor w -fill y -expand true

    label $f.title -text [msgcat::mc {Default Menu}]
    menubutton $f.color -relief raised -text [msgcat::mc {Color}] \
	-menu $f.color.menu

    grid $f.title $f.color -padx 4 -sticky w

    set id [colorbar list id]
    set m $f.color.menu
    menu $m
    foreach ii $id {
	set name [colorbar get name $ii]
	$m add radiobutton -label [msgcat::mc $name] \
	    -variable prefs(colorbar,map)
    }
    $m add separator
    $m add checkbutton -label [msgcat::mc {Invert Colormap}] \
	-variable prefs(colorbar,invert)
    $m add separator
    $m add checkbutton -label [msgcat::mc {Colorbar Numerics}] \
	-variable pview(colorbar,numerics)

    # Truecolor
    set f $w.color.truecolor.f
    frame $f
    pack $f -anchor w -fill y -expand true

    label $f.title -text [msgcat::mc {Truecolor Colorbar}]
    radiobutton $f.full \
	-text [msgcat::mc {Update Full Screen}] \
	-variable colorbar(area) -value 0 -command PrefsColorbarArea
    radiobutton $f.x128 -text {128x128} \
	-variable colorbar(area) -value 128 -command PrefsColorbarArea
    radiobutton $f.x256 -text {256x256} \
	-variable colorbar(area) -value 256 -command PrefsColorbarArea
    radiobutton $f.x512 -text {512x512} \
	-variable colorbar(area) -value 512 -command PrefsColorbarArea
    radiobutton $f.center -text [msgcat::mc {About Center}] \
	-variable colorbar(mode) -value center -command PrefsColorbarArea
    radiobutton $f.click \
	-text [msgcat::mc {About Mouse Click}] \
	-variable colorbar(mode) -value click -command PrefsColorbarArea

    grid $f.title -padx 4 -sticky w
    grid $f.full $f.x128 $f.x256 $f.x512 -padx 4 -sticky w
    grid $f.center $f.click - -padx 4 -sticky w
}

proc ColorButtons {} {
    global ds9
    global colorbar

    set ids [colorbar list id]

    frame $ds9(buttons).color1
    for {set i 0} {$i<9} {incr i} {
	set id [lindex $ids $i]
	set title [colorbar get name $id]
	set name [string tolower [msgcat::mc $title]]
	RadioButton $ds9(buttons).color1.$i $name \
	    colorbar(map) $title "ChangeColormapID $id"
    }
    RadioButton $ds9(buttons).color1.more \
	[string tolower [msgcat::mc {More}]] \
	buttons(majorCurrent) $ds9(buttons).color2 MajorButton

    frame $ds9(buttons).color2
    for {set i 9} {$i<18} {incr i} {
	set id [lindex $ids $i]
	set title [colorbar get name $id]
	set name [string tolower [msgcat::mc $title]]
	RadioButton $ds9(buttons).color2.$i $name \
	    colorbar(map) $title "ChangeColormapID $id"
    }
    RadioButton $ds9(buttons).color2.more \
	[string tolower [msgcat::mc {More}]] \
	buttons(majorCurrent) $ds9(buttons).color1 MajorButton
}

proc UpdateColorMenu {} {
    global ds9
    global current
    global colorbar

    global debug
    if {$debug(tcl,update)} {
	puts "UpdateColorMenu"
    }

    if {$current(frame) != {}} {
	if {[$current(frame) get type] == {rgb}} {
	    for {set i $colorbar(start)} {$i<$colorbar(count)} {incr i} {
		$ds9(mb).color entryconfig $i -state disabled
	    }

	    for {set i 0} {$i<$colorbar(button1)} {incr i} {
		$ds9(buttons).color1.$i configure -state disabled
	    }
	    for {set i $colorbar(button1)} {$i<$colorbar(button2)} {incr i} {
		$ds9(buttons).color2.$i configure -state disabled
	    }
	} else {
	    for {set i $colorbar(start)} {$i<$colorbar(count)} {incr i} {
		$ds9(mb).color entryconfig $i -state normal
	    }

	    for {set i 0} {$i<$colorbar(button1)} {incr i} {
		$ds9(buttons).color1.$i configure -state normal
	    }
	    for {set i $colorbar(button1)} {$i<$colorbar(button2)} {incr i} {
		$ds9(buttons).color2.$i configure -state normal
	    }
	}
    } else {
	for {set i $colorbar(start)} {$i<$colorbar(count)} {incr i} {
	    $ds9(mb).color entryconfig $i -state normal
	}

	for {set i 0} {$i<$colorbar(button1)} {incr i} {
	    $ds9(buttons).color1.$i configure -state normal
	}
	for {set i $colorbar(button1)} {$i<$colorbar(button2)} {incr i} {
	    $ds9(buttons).color2.$i configure -state normal
	}
    }

    # for aqua
    switch $ds9(wm) {
	x11 -
	win32 {}
	aqua {
	    global colorbar
	    set colorbar(map) $colorbar(map)
	}
    }
}

