#  Copyright (C) 1999-2008
#  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
#  For conditions of distribution and use, see copyright notice in "copyright"

package provide DS9 1.0

proc OpenFileDialog {varname} {
    return [FileDialog $varname tk_getOpenFile]
}

proc SaveFileDialog {varname} {
    return [FileDialog $varname tk_getSaveFile]
}

proc FileDialog {varname which} {
    global ds9

    switch -- $ds9(dialog) {
	motif {return [FileDialogMotif $varname $which]}
	windows {return [FileDialogWindows $varname $which]}
	native {return [FileDialogNative $varname $which]}
    }
}

proc FileDialogMotif {varname which} {
    upvar #0 $varname var

    global ds9
    global tk_strictMotif

    set tk_strictMotif 1

    switch $ds9(wm) {
	x11 {
	    # Theres a bug with strictmotif. 
	    # If tk_strictMotif is set to 1, buttons are
	    # rendered smaller than if 0.
	    set result [$which \
			    -filetypes $var(types) \
			    -defaulttype $var(type) \
			    -defaultfilter $var(filter) \
			    -initialdir $var(directory) \
			    -initialfile $var(file) \
			    -parent $ds9(top)]
	}
	win32 -
	aqua {
	    switch -- $which {
		tk_getOpenFile {set type open}
		tk_getSaveFile {set type save}
	    }
	    set result [::tk::MotifFDialog $type \
			    -filetypes $var(types) \
			    -defaulttype $var(type) \
			    -defaultfilter $var(filter) \
			    -initialdir $var(directory) \
			    -initialfile $var(file) \
			    -parent $ds9(top)]
	}
    }
    set tk_strictMotif 0

    if {$result != {}} {
	set var(file) [file tail $result]
	set var(directory) [file dirname $result]
    }
    set var(type) $ds9(-defaulttype)
    set var(filter) $ds9(-defaultfilter)

    return $result
}

proc FileDialogWindows {varname which} {
    upvar #0 $varname var
    global ds9

    switch $ds9(wm) {
	x11 {
	    set result [$which \
			    -filetypes $var(types) \
			    -defaulttype $var(type) \
			    -initialdir $var(directory) \
			    -initialfile $var(file) \
			    -parent $ds9(top)]
	}
	win32 -
	aqua {
	    switch -- $which {
		tk_getOpenFile {set type open}
		tk_getSaveFile {set type save}
	    }
	    set result [::tk::dialog::file:: $type \
			    -filetypes $var(types) \
			    -defaulttype $var(type) \
			    -initialdir $var(directory) \
			    -initialfile $var(file) \
			    -parent $ds9(top)]
	}
    }

    if {$result != {}} {
	set var(file) [file tail $result]
	set var(directory) [file dirname $result]
    }
    set var(type) $ds9(-defaulttype)

    return $result
}


proc FileDialogNative {varname which} {
    upvar #0 $varname var
    global ds9

    if [catch {$which -filetypes $var(types) -initialdir $var(directory) -initialfile $var(file) -parent $ds9(top)} result] {

	# must have a bad file name, just clear and try again
	set var(file) {}
	set var(directory) {}
	if [catch {$which -filetypes $var(types) -parent $ds9(top)} result] {

	    #ok, something is really wrong
	    catch {$which -parent $ds9(top)} result
	}
    }

    if {$result != {}} {
	set var(file) [file tail $result]
	set var(directory) [file dirname $result]
    }

    return $result
}


proc FileLast {varname fn} {
    upvar #0 $varname var

    set var(file) [file tail $fn]
}

proc FileLastFull {varname fn} {
    upvar #0 $varname var

    set var(file) [file tail $fn]
    set var(directory) [file dirname $fn]
}
